Console display for Doodle-Dashboard
====================================

.. image:: https://img.shields.io/pypi/v/doodle-dashboard-display-console.svg
    :target: https://pypi.org/project/doodle-dashboard-display-console/
    :alt: Latest version

.. image:: https://travis-ci.org/SketchingDev/Doodle-Dashboard-Display-Console.svg?branch=master
    :target: https://travis-ci.org/SketchingDev/Doodle-Dashboard-Display-Console
    :alt: Build status
